<a id="types-aiobotocore-kendra"></a>

# types-aiobotocore-kendra

[![PyPI - types-aiobotocore-kendra](https://img.shields.io/pypi/v/types-aiobotocore-kendra.svg?color=blue)](https://pypi.org/project/types-aiobotocore-kendra)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-kendra.svg?color=blue)](https://pypi.org/project/types-aiobotocore-kendra)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-kendra?color=blue)](https://pypistats.org/packages/types-aiobotocore-kendra)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.kendra 2.3.1](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kendra.html#kendra)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.5.14](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-kendra docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kendra/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-kendra](#types-aiobotocore-kendra)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `kendra`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `kendra` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[kendra]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[kendra]'


# standalone installation
python -m pip install types-aiobotocore-kendra
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-kendra
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[kendra]` in your environment:

```bash
python -m pip install 'types-aiobotocore[kendra]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[kendra]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[kendra]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[kendra]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[kendra]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[kendra]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[kendra]` in your environment:

```bash
python -m pip install 'types-aiobotocore[kendra]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[kendra]` in your environment:

```bash
python -m pip install 'types-aiobotocore[kendra]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`kendraClient` provides annotations for `session.create_client("kendra")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_kendra import kendraClient

session = get_session()
async with session.create_client("kendra") as client:
    client: kendraClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="literals"></a>

### Literals

`types_aiobotocore_kendra.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from types_aiobotocore_kendra.literals import (
    AdditionalResultAttributeValueTypeType,
    ConditionOperatorType,
    ConfluenceAttachmentFieldNameType,
    ConfluenceBlogFieldNameType,
    ConfluencePageFieldNameType,
    ConfluenceSpaceFieldNameType,
    ConfluenceVersionType,
    ContentTypeType,
    DataSourceStatusType,
    DataSourceSyncJobStatusType,
    DataSourceTypeType,
    DatabaseEngineTypeType,
    DocumentAttributeValueTypeType,
    DocumentStatusType,
    EndpointTypeType,
    EntityTypeType,
    ErrorCodeType,
    ExperienceStatusType,
    FaqFileFormatType,
    FaqStatusType,
    FsxFileSystemTypeType,
    HighlightTypeType,
    IndexEditionType,
    IndexStatusType,
    IntervalType,
    KeyLocationType,
    MetricTypeType,
    ModeType,
    OrderType,
    PersonaType,
    PrincipalMappingStatusType,
    PrincipalTypeType,
    QueryIdentifiersEnclosingOptionType,
    QueryResultTypeType,
    QuerySuggestionsBlockListStatusType,
    QuerySuggestionsStatusType,
    ReadAccessTypeType,
    RelevanceTypeType,
    SalesforceChatterFeedIncludeFilterTypeType,
    SalesforceKnowledgeArticleStateType,
    SalesforceStandardObjectNameType,
    ScoreConfidenceType,
    ServiceNowAuthenticationTypeType,
    ServiceNowBuildVersionTypeType,
    SharePointVersionType,
    SlackEntityType,
    SortOrderType,
    ThesaurusStatusType,
    UserContextPolicyType,
    UserGroupResolutionModeType,
    WarningCodeType,
    WebCrawlerModeType,
    kendraServiceName,
    ServiceName,
    ResourceServiceName,
    RegionName,
)

def check_value(value: AdditionalResultAttributeValueTypeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_kendra.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_kendra.type_defs import (
    AccessControlListConfigurationTypeDef,
    AclConfigurationTypeDef,
    AdditionalResultAttributeTypeDef,
    AdditionalResultAttributeValueTypeDef,
    AssociateEntitiesToExperienceRequestRequestTypeDef,
    AssociateEntitiesToExperienceResponseTypeDef,
    AssociatePersonasToEntitiesRequestRequestTypeDef,
    AssociatePersonasToEntitiesResponseTypeDef,
    AttributeFilterTypeDef,
    AuthenticationConfigurationTypeDef,
    BasicAuthenticationConfigurationTypeDef,
    BatchDeleteDocumentRequestRequestTypeDef,
    BatchDeleteDocumentResponseFailedDocumentTypeDef,
    BatchDeleteDocumentResponseTypeDef,
    BatchGetDocumentStatusRequestRequestTypeDef,
    BatchGetDocumentStatusResponseErrorTypeDef,
    BatchGetDocumentStatusResponseTypeDef,
    BatchPutDocumentRequestRequestTypeDef,
    BatchPutDocumentResponseFailedDocumentTypeDef,
    BatchPutDocumentResponseTypeDef,
    CapacityUnitsConfigurationTypeDef,
    ClearQuerySuggestionsRequestRequestTypeDef,
    ClickFeedbackTypeDef,
    ColumnConfigurationTypeDef,
    ConfluenceAttachmentConfigurationTypeDef,
    ConfluenceAttachmentToIndexFieldMappingTypeDef,
    ConfluenceBlogConfigurationTypeDef,
    ConfluenceBlogToIndexFieldMappingTypeDef,
    ConfluenceConfigurationTypeDef,
    ConfluencePageConfigurationTypeDef,
    ConfluencePageToIndexFieldMappingTypeDef,
    ConfluenceSpaceConfigurationTypeDef,
    ConfluenceSpaceToIndexFieldMappingTypeDef,
    ConnectionConfigurationTypeDef,
    ContentSourceConfigurationTypeDef,
    CorrectionTypeDef,
    CreateDataSourceRequestRequestTypeDef,
    CreateDataSourceResponseTypeDef,
    CreateExperienceRequestRequestTypeDef,
    CreateExperienceResponseTypeDef,
    CreateFaqRequestRequestTypeDef,
    CreateFaqResponseTypeDef,
    CreateIndexRequestRequestTypeDef,
    CreateIndexResponseTypeDef,
    CreateQuerySuggestionsBlockListRequestRequestTypeDef,
    CreateQuerySuggestionsBlockListResponseTypeDef,
    CreateThesaurusRequestRequestTypeDef,
    CreateThesaurusResponseTypeDef,
    CustomDocumentEnrichmentConfigurationTypeDef,
    DataSourceConfigurationTypeDef,
    DataSourceGroupTypeDef,
    DataSourceSummaryTypeDef,
    DataSourceSyncJobMetricTargetTypeDef,
    DataSourceSyncJobMetricsTypeDef,
    DataSourceSyncJobTypeDef,
    DataSourceToIndexFieldMappingTypeDef,
    DataSourceVpcConfigurationTypeDef,
    DatabaseConfigurationTypeDef,
    DeleteDataSourceRequestRequestTypeDef,
    DeleteExperienceRequestRequestTypeDef,
    DeleteFaqRequestRequestTypeDef,
    DeleteIndexRequestRequestTypeDef,
    DeletePrincipalMappingRequestRequestTypeDef,
    DeleteQuerySuggestionsBlockListRequestRequestTypeDef,
    DeleteThesaurusRequestRequestTypeDef,
    DescribeDataSourceRequestRequestTypeDef,
    DescribeDataSourceResponseTypeDef,
    DescribeExperienceRequestRequestTypeDef,
    DescribeExperienceResponseTypeDef,
    DescribeFaqRequestRequestTypeDef,
    DescribeFaqResponseTypeDef,
    DescribeIndexRequestRequestTypeDef,
    DescribeIndexResponseTypeDef,
    DescribePrincipalMappingRequestRequestTypeDef,
    DescribePrincipalMappingResponseTypeDef,
    DescribeQuerySuggestionsBlockListRequestRequestTypeDef,
    DescribeQuerySuggestionsBlockListResponseTypeDef,
    DescribeQuerySuggestionsConfigRequestRequestTypeDef,
    DescribeQuerySuggestionsConfigResponseTypeDef,
    DescribeThesaurusRequestRequestTypeDef,
    DescribeThesaurusResponseTypeDef,
    DisassociateEntitiesFromExperienceRequestRequestTypeDef,
    DisassociateEntitiesFromExperienceResponseTypeDef,
    DisassociatePersonasFromEntitiesRequestRequestTypeDef,
    DisassociatePersonasFromEntitiesResponseTypeDef,
    DocumentAttributeConditionTypeDef,
    DocumentAttributeTargetTypeDef,
    DocumentAttributeTypeDef,
    DocumentAttributeValueCountPairTypeDef,
    DocumentAttributeValueTypeDef,
    DocumentInfoTypeDef,
    DocumentMetadataConfigurationTypeDef,
    DocumentRelevanceConfigurationTypeDef,
    DocumentTypeDef,
    DocumentsMetadataConfigurationTypeDef,
    EntityConfigurationTypeDef,
    EntityDisplayDataTypeDef,
    EntityPersonaConfigurationTypeDef,
    ExperienceConfigurationTypeDef,
    ExperienceEndpointTypeDef,
    ExperienceEntitiesSummaryTypeDef,
    ExperiencesSummaryTypeDef,
    FacetResultTypeDef,
    FacetTypeDef,
    FailedEntityTypeDef,
    FaqStatisticsTypeDef,
    FaqSummaryTypeDef,
    FsxConfigurationTypeDef,
    GetQuerySuggestionsRequestRequestTypeDef,
    GetQuerySuggestionsResponseTypeDef,
    GetSnapshotsRequestRequestTypeDef,
    GetSnapshotsResponseTypeDef,
    GoogleDriveConfigurationTypeDef,
    GroupMembersTypeDef,
    GroupOrderingIdSummaryTypeDef,
    GroupSummaryTypeDef,
    HierarchicalPrincipalTypeDef,
    HighlightTypeDef,
    HookConfigurationTypeDef,
    IndexConfigurationSummaryTypeDef,
    IndexStatisticsTypeDef,
    InlineCustomDocumentEnrichmentConfigurationTypeDef,
    JsonTokenTypeConfigurationTypeDef,
    JwtTokenTypeConfigurationTypeDef,
    ListDataSourceSyncJobsRequestRequestTypeDef,
    ListDataSourceSyncJobsResponseTypeDef,
    ListDataSourcesRequestRequestTypeDef,
    ListDataSourcesResponseTypeDef,
    ListEntityPersonasRequestRequestTypeDef,
    ListEntityPersonasResponseTypeDef,
    ListExperienceEntitiesRequestRequestTypeDef,
    ListExperienceEntitiesResponseTypeDef,
    ListExperiencesRequestRequestTypeDef,
    ListExperiencesResponseTypeDef,
    ListFaqsRequestRequestTypeDef,
    ListFaqsResponseTypeDef,
    ListGroupsOlderThanOrderingIdRequestRequestTypeDef,
    ListGroupsOlderThanOrderingIdResponseTypeDef,
    ListIndicesRequestRequestTypeDef,
    ListIndicesResponseTypeDef,
    ListQuerySuggestionsBlockListsRequestRequestTypeDef,
    ListQuerySuggestionsBlockListsResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListThesauriRequestRequestTypeDef,
    ListThesauriResponseTypeDef,
    MemberGroupTypeDef,
    MemberUserTypeDef,
    OneDriveConfigurationTypeDef,
    OneDriveUsersTypeDef,
    PersonasSummaryTypeDef,
    PrincipalTypeDef,
    ProxyConfigurationTypeDef,
    PutPrincipalMappingRequestRequestTypeDef,
    QueryRequestRequestTypeDef,
    QueryResultItemTypeDef,
    QueryResultTypeDef,
    QuerySuggestionsBlockListSummaryTypeDef,
    RelevanceFeedbackTypeDef,
    RelevanceTypeDef,
    ResponseMetadataTypeDef,
    S3DataSourceConfigurationTypeDef,
    S3PathTypeDef,
    SalesforceChatterFeedConfigurationTypeDef,
    SalesforceConfigurationTypeDef,
    SalesforceCustomKnowledgeArticleTypeConfigurationTypeDef,
    SalesforceKnowledgeArticleConfigurationTypeDef,
    SalesforceStandardKnowledgeArticleTypeConfigurationTypeDef,
    SalesforceStandardObjectAttachmentConfigurationTypeDef,
    SalesforceStandardObjectConfigurationTypeDef,
    ScoreAttributesTypeDef,
    SearchTypeDef,
    SeedUrlConfigurationTypeDef,
    ServerSideEncryptionConfigurationTypeDef,
    ServiceNowConfigurationTypeDef,
    ServiceNowKnowledgeArticleConfigurationTypeDef,
    ServiceNowServiceCatalogConfigurationTypeDef,
    SharePointConfigurationTypeDef,
    SiteMapsConfigurationTypeDef,
    SlackConfigurationTypeDef,
    SortingConfigurationTypeDef,
    SpellCorrectedQueryTypeDef,
    SpellCorrectionConfigurationTypeDef,
    SqlConfigurationTypeDef,
    StartDataSourceSyncJobRequestRequestTypeDef,
    StartDataSourceSyncJobResponseTypeDef,
    StatusTypeDef,
    StopDataSourceSyncJobRequestRequestTypeDef,
    SubmitFeedbackRequestRequestTypeDef,
    SuggestionHighlightTypeDef,
    SuggestionTextWithHighlightsTypeDef,
    SuggestionTypeDef,
    SuggestionValueTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TextDocumentStatisticsTypeDef,
    TextWithHighlightsTypeDef,
    ThesaurusSummaryTypeDef,
    TimeRangeTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateDataSourceRequestRequestTypeDef,
    UpdateExperienceRequestRequestTypeDef,
    UpdateIndexRequestRequestTypeDef,
    UpdateQuerySuggestionsBlockListRequestRequestTypeDef,
    UpdateQuerySuggestionsConfigRequestRequestTypeDef,
    UpdateThesaurusRequestRequestTypeDef,
    UrlsTypeDef,
    UserContextTypeDef,
    UserGroupResolutionConfigurationTypeDef,
    UserIdentityConfigurationTypeDef,
    UserTokenConfigurationTypeDef,
    WarningTypeDef,
    WebCrawlerConfigurationTypeDef,
    WorkDocsConfigurationTypeDef,
)

def get_structure() -> AccessControlListConfigurationTypeDef:
    return {
      ...
    }
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-kendra` version is the same as related `aiobotocore` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kendra/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
